@@ -1,7 +1,6 @@
 from gitlab.base import RequiredOptional, RESTManager, RESTObject
 from gitlab.mixins import CRUDMixin, NoUpdateMixin, ObjectDeleteMixin, SaveMixin
 
-
 __all__ = [
     "ProjectRelease",
     "ProjectReleaseManager",
@@ -24,7 +23,7 @@ class ProjectReleaseManager(NoUpdateMixin, RESTManager):
     )
 
 
-class ProjectReleaseLink(RESTObject, ObjectDeleteMixin, SaveMixin):
+class ProjectReleaseLink(ObjectDeleteMixin, SaveMixin, RESTObject):
     pass
 
 
